@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides the default implementation for bookmarks in Orca."""
 
@@ -77,9 +77,10 @@ class Bookmarks:
         # those spots.  These spots are known as 'bookmarks'. 
         #
         utterances = [_('bookmark entered')]
-        utterances.extend(self._script.speechGenerator.getSpeech( \
-                          context.getCurrentAccessible(), False))
-        speech.speakUtterances(utterances)
+        utterances.extend(
+            self._script.speechGenerator.generateSpeech(
+                context.getCurrentAccessible()))
+        speech.speak(utterances)
 
     def bookmarkCurrentWhereAmI(self, inputEvent):
         """ Report "Where am I" information for this bookmark relative to the 
