@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.29.91"
+version     = "2.29.92"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/wwalker/orca/bld"
+prefix      = "/home/wwalker/git.gnome.org/orca/bld"
 
 # The package name (should be "orca").
 #
